
module silo(r,h)
{
	zh=h-r;
	translate([0,0,0])
		cylinder(r=r,h=zh,center=true,$fn=50);
	translate([0,0,zh/2])
		sphere(r,$fn=50);
}

module syringe_tip_solid()
{
	// Create an inner barrel
	translate([0,0,20.1/2])
		cylinder(r=2.5,h=20.1,center=true,$fn=50);

	// Some variables
	tip_ro=6;	// Tip outside radius
	silos=8;	// Number of silos
	silo_h=13.85;	// Height of silos
	silo_r=0.935;	// Radius of silos
	silo_ro=tip_ro-silo_r;	// Radius of silo center axes
	bbl_ro=4.64;	// Outer barrel radius

	// create grip ridges ("silos")
	for (i = [0:silos-1]) {
		*echo(360*i/silos, sin(360*i/silos)*80, cos(360*i/silos)*80);
		translate([sin(360*i/silos)*silo_ro,cos(360*i/silos)*silo_ro,(silo_h-silo_r)/2])
			silo(silo_r,silo_h);
	}

	// Create a base
	translate([0,0,2.0/2])
		cylinder(r=6,h=2.0,center=true,$fn=50);

	// Create a chamfered barrel
	difference() {
		translate([0,0,19.7/2])
			cylinder(r=bbl_ro,h=19.7,center=true,$fn=50);
		difference() {
			translate([0,0,21.35/2])
				cylinder(r=20,h=21.35,center=true,$fn=50);
			translate([0,0,23.0/2])
				cylinder(r1=17.4242,r2=0,h=23.0,center=true,$fn=50);
		}
	}

	// Create a tapered nozzle
	tip_h=28.5;	// Total height of the syringe tip
	nozzle_h=8.4;	// Height of the nozzle
	nozzle_r_tip=2.0;	// Radius at the very tip of the nozzle
	nozzle_r_taper=0.2; // Increase of nozzle radius over its length
	nozzle_r_base=nozzle_r_tip+nozzle_r_taper/nozzle_h*tip_h;
	translate([0,0,tip_h/2])
		cylinder(r1=nozzle_r_base,r2=nozzle_r_tip,h=tip_h,center=true,$fn=50);

}

module syringe_tip_hole()
{
	// Create a central hole
	translate([0,0,28.5/2])
		cylinder(r=1.0,h=30.0,center=true,$fn=50);
	// Create a tapered inlet
	taper_h=15.5;	// Height of the syringe tapered end
	taper_r_base=3.62; // Radius of syringe tapered end at base
	taper_r_top=2.75; // Radius of syringe tapered end at top
	inlet_h=16.0;	// height of the tip inlet
	inlet_r_taper=(taper_r_base-taper_r_top)/taper_h*inlet_h; // Increase of inlet hole radius over its length
	inlet_r_top=2.5;	// Radius at the top of the inlet hole
	inlet_r_base=inlet_r_top+inlet_r_taper; // Radius at the base of the inlet hole
	translate([0,0,inlet_h/2])
		cylinder(r1=inlet_r_base,r2=inlet_r_top,h=inlet_h+1,center=true,$fn=50);
	// Create a transition between the tapered inlet and the central hole
	translate([0,0,inlet_h])
		sphere(r=inlet_r_top,center=true,$fn=50);
}

module syringe_tip()
{
	difference() {
		syringe_tip_solid();
		syringe_tip_hole();
	}
}

syringe_tip();



